/***************************************************************************
* Copyright (c) 2017, Sylvain Corlay and Johan Mabille                     *
*                                                                          *
* Distributed under the terms of the BSD 3-Clause License.                 *
*                                                                          *
* The full license is in the file LICENSE, distributed with this software. *
****************************************************************************/

#ifndef XPLOT_MAPS_CONFIG_HPP
#define XPLOT_MAPS_CONFIG_HPP

#define XPLOT_MAPS_DIR "D:/bld/xplot_1579711110659/_h_env/Library/share/xplot/map_data/"

#endif
